import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "Suspense"
      }), " позволяет нам фоллбек (", jsx(_components.code, {
        children: "fallback"
      }), ") при загрузке данных. Это отлично подходит для первой загрузки, но если при каждом изменении данных возвращать фоллбек то это может ухудшить UX."]
    }), "\n", jsxs(_components.p, {
      children: ["Мы можем избежать возврата к фоллбеку, используя ", jsx(_components.code, {
        children: "useTransition"
      }), ". Он предоставляет собой функцию-обертку для создания перехода и индикатор его состояния. Функция-обертка позволяет создать транзакцию, которая не фиксирует изменения пока все внутренние асинхронные события не будут завершены."]
    }), "\n", jsxs(_components.p, {
      children: ["На практике это означает, что пока поток управления остановлен мы не меняем состояние пока не завершим все бекграунд процессы. Считывание ", jsx(_components.code, {
        children: "Ресурса"
      }), " под существующими границами добавят его к переходу. Однако любые новые вложенные компоненты ", jsx(_components.code, {
        children: "Suspense"
      }), " будут показывать ", jsx(_components.code, {
        children: "fallback"
      }), ", если они не завершили загрузку до того, как станут видимыми."]
    }), "\n", jsxs(_components.p, {
      children: ["Обратите внимание, когда вы перемещаетесь по вкладкам в нашем примере, мы продолжаем видеть, как контент исчезает и нам показывается ", jsx(_components.code, {
        children: "fallback"
      }), " с индикатором загрузки. Давайте добавим переход в наш компонент ", jsx(_components.code, {
        children: "App"
      }), ". Для начала создадим функцию ", jsx(_components.code, {
        children: "updateTab"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [pending, start] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "useTransition"
        }), "();\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "updateTab"
        }), " = (", jsx(_components.span, {
          className: "hljs-params",
          children: "index"
        }), ") => ", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "start"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setTab"
        }), "(index));\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "useTransition"
      }), " возвращает кортеж с ", jsx(_components.code, {
        children: "Сигналом"
      }), " - индикатором состояния, который мы назвали ", jsx(_components.code, {
        children: "pending"
      }), ", а вторым аргументом мы получаем функцию-обертку ", jsx(_components.code, {
        children: "start"
      }), " с помощь которой мы обернем наш ", jsx(_components.code, {
        children: "updateTab"
      })]
    }), "\n", jsxs(_components.p, {
      children: ["Мы используем ", jsx(_components.code, {
        children: "Сигнал"
      }), " ", jsx(_components.code, {
        children: "pending"
      }), " чтобы добавить класс в наш ", jsx(_components.code, {
        children: "div"
      }), " контейнер:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: ["<div ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "class"
        }), "=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"tab\""
        }), " classList={{ ", jsx(_components.span, {
          className: "hljs-attr",
          children: "pending"
        }), ": ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "pending"
        }), "() }}>\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["После введения ", jsx(_components.code, {
        children: "useTransition"
      }), " изменения вкладок выглядят куда более плавными."]
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-28f72376.js.map
