import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "コンテキストはストアのための素晴らしいツールです。インジェクションを処理し、所有権をリアクティブグラフに結びつけ、廃棄を自動的に管理し、Solid のきめ細かいレンダリングにより、レンダリングのオーバーヘッドもありません。"
    }), "\n", jsxs(_components.p, {
      children: ["しかし、コンテキストが過剰になることもあります。代替案としては、リアクティブシステムを直接使用することです。例えば、グローバルスコープで Signal を生成し、他のモジュールが使えるように ", jsx(_components.code, {
        children: "export"
      }), " することでグローバルなリアクティブデータストアを構築できます:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-js",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " { createSignal } ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'solid-js'"
        }), ";\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n\n", jsx(_components.span, {
          className: "hljs-comment",
          children: "// どこか別の場所で:"
        }), "\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "import"
        }), " counter ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "from"
        }), " ", jsx(_components.span, {
          className: "hljs-string",
          children: "'./counter'"
        }), ";\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [count, setCount] = counter;\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Solid のリアクティビティは普遍的な概念です。コンポーネントの内側か外側かは関係ありません。グローバルな状態とローカルな状態という別々の概念はありません。すべてが同じものなのです。"
    }), "\n", jsxs(_components.p, {
      children: ["唯一の制限は、すべての計算（Effect/Memo）がリアクティブルート（", jsx(_components.code, {
        children: "createRoot"
      }), "）の下で作成される必要があることです。Solid の ", jsx(_components.code, {
        children: "render"
      }), " はこれを自動的に行います。"]
    }), "\n", jsxs(_components.p, {
      children: ["このチュートリアルでは、", jsx(_components.code, {
        children: "counter.tsx"
      }), " がそのようなグローバルストアです。これを使用するには、", jsx(_components.code, {
        children: "main.tsx"
      }), " のコンポーネントを次のように変更します:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " { count, doubleCount, increment } = counter;\n\n", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "type"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"button\""
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "onClick"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{increment}"
            }), ">"]
          }), "\n    {count()} {doubleCount()}\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "button"
            }), ">"]
          })]
        }), "\n);\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "したがって、計算を含む複雑な独自のグローバルストアを使用する場合は、必ずルートを作成してください。あるいは、コンテキストを使用することをお勧めします。"
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-40a893c6.js.map
