import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["Иногда мы хотим координировать отрисовку нескольких компонентов. Один из возможных способов реализации это поместить все эти компоненты в единый ", jsx(_components.code, {
        children: "Suspense"
      }), ", но это означает, что у нас будет лишь одно состояние загрузки. При использовании данного способа наш ", jsx(_components.code, {
        children: "Suspense"
      }), " будет ожидать пока все компоненты внутри не будут загружены, что очень часто далеко от желаемого результата. В Solid для таких задач существует ", jsx(_components.code, {
        children: "SuspenseList"
      }), " компонент специально для решения подобных задач."]
    }), "\n", jsxs(_components.p, {
      children: ["Для примера давайте возьмём несколько ", jsx(_components.code, {
        children: "Suspense"
      }), " компонентов. Если мы обернём их в ", jsx(_components.code, {
        children: "SuspenseList"
      }), " с конфигурацией ", jsx(_components.code, {
        children: "revealOrder=\"forwards\""
      }), ", то они будут загружены сверху вниз, вне зависимости от того, в каком порядке они загрузились. Это может быть полезно для случаев, когда мы хотим избежать прыжков контента на нашей странице. Помимо ", jsx(_components.code, {
        children: "forwards"
      }), " у ", jsx(_components.code, {
        children: "revealOrder"
      }), " есть ещё опции в виде ", jsx(_components.code, {
        children: "backwards"
      }), " и ", jsx(_components.code, {
        children: "together"
      }), ", первая из которых рендерит контент в обратном порядке, а вторая ожидает все ", jsx(_components.code, {
        children: "Suspense"
      }), " компоненты перед тем как загрузить. ", jsx(_components.code, {
        children: "SuspenseList"
      }), " имеет ещё одну опцию — ", jsx(_components.code, {
        children: "tail"
      }), " с вариантами ", jsx(_components.code, {
        children: "hidden"
      }), " и ", jsx(_components.code, {
        children: "collapsed"
      }), ". Эти опции переписывают стандартное поведение ", jsx(_components.code, {
        children: "SuspenseList"
      }), ", которое показывает все фоллбеки. В случае с ", jsx(_components.code, {
        children: "hidden"
      }), " не будет показан ни один фоллбек, а в случае с ", jsx(_components.code, {
        children: "collapsed"
      }), " будет показан следующий в списке по направлению, которое мы назначили в ", jsx(_components.code, {
        children: "revealOrder"
      }), "."]
    }), "\n", jsxs(_components.p, {
      children: ["Наш текущий пример выглядит не очень с точки зрения заглушек с загрузкой. Пока он независимо загружает наши данные мы часто показываем несколько заглушек в зависимости от порядка в котором загружаются данные. Давайте обернём наш ", jsx(_components.code, {
        children: "ProfilePage"
      }), " компонент в ", jsx(_components.code, {
        children: "SuspenseList"
      }), " со следующими настройками:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "SuspenseList"
        }), " revealOrder=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"forwards\""
        }), " tail=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"collapsed\""
        }), ">\n  ", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileDetails"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "user"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.user}"
            }), " />"]
          })
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "h2"
            }), ">"]
          }), "Loading posts...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h2"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileTimeline"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "posts"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.posts}"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "h2"
            }), ">"]
          }), "Loading fun facts...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h2"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileTrivia"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "trivia"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.trivia}"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "SuspenseList"
        }), ">\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-469bb7dc.js.map
