import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    pre: "pre",
    code: "code",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "JSX は実際の DOM 要素を作成するので、Solid では代入によって DOM 要素への参照を常に得ることができます。例えば:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " myDiv = ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          }), "My Element", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), ";\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "しかし、要素を分割せずに 1 つの連続した JSX テンプレートにまとめることで、Solid がその作成をより最適化できるというメリットがあります。"
    }), "\n", jsxs(_components.p, {
      children: ["その代わりに、Solid では ", jsx(_components.code, {
        children: "ref"
      }), " 属性を使用して要素への参照を取得できます。ref は基本的には、上の例のように、ドキュメントの DOM にアタッチされる前の作成時に発生する代入です。変数を宣言し、それを ", jsx(_components.code, {
        children: "ref"
      }), " 属性として渡すだけで、その変数に割り当てられます:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "let"
        }), " myDiv;\n\n", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "ref"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{myDiv}"
            }), ">"]
          }), "My Element", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "div"
            }), ">"]
          })]
        }), "\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "それでは、canvas 要素への参照を取得して、アニメーションさせてみましょう:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<canvas ref={canvas} width=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"256\""
        }), " height=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"256\""
        }), " />\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "ref は、コールバック関数の形をとることもできます。これはロジックをカプセル化するのに便利で、特に要素がアタッチされるまで待つ必要がない場合に便利です。例えば:"
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<div ref={", jsxs(_components.span, {
          className: "hljs-function",
          children: [jsx(_components.span, {
            className: "hljs-params",
            children: "el"
          }), " =>"]
        }), " ", jsx(_components.span, {
          className: "hljs-comment",
          children: "/* el を使って何かする... */"
        }), "}>", jsx(_components.span, {
          className: "hljs-title class_",
          children: "My"
        }), " ", jsx(_components.span, {
          className: "hljs-title class_",
          children: "Element"
        }), "</div>\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-55287428.js.map
