import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["Während ", jsx(_components.code, {
        children: "lazy"
      }), " und ", jsx(_components.code, {
        children: "createResource"
      }), " auch allein benutzt werden können, bringt Solid einen Mechanismus mit, um koordiniert unterschiedliche asynchrone Events anzuzeigen. ", jsx(_components.code, {
        children: "Suspense"
      }), " dient als Begrenzung, die ein Fallback anstelle eines teilweise geladenen Inhalts anzeigt, bis alle asynchronen Anfragen darin beantwortet sind."]
    }), "\n", jsxs(_components.p, {
      children: ["Das kann die Nutzererfahrung verbessern, indem visuelles Stottern, das durch zu viele partielle Ladezustände ausgelöst wird, entfernt wird. ", jsx(_components.code, {
        children: "Suspense"
      }), " erkennt automatisch alle Nachkommen, die asynchron sind und handelt entsprechend. Man kann so viele ", jsx(_components.code, {
        children: "Suspense"
      }), "-Komponenten schachteln, wie man möchte und nur der nächste Vorfahr wird zum Fallback transformiert, wenn der Ladezustand erkannt wurde."]
    }), "\n", jsxs(_components.p, {
      children: ["Fügen wir eine ", jsx(_components.code, {
        children: "Suspense"
      }), "-Komponente zu unserem Nachlade-Beispiel hinzu:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<>\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "h1"
            }), ">"]
          }), "Welcome", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h1"
            }), ">"]
          })]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "p"
            }), ">"]
          }), "Loading...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "p"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Greeting"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "name"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"Jake\""
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n</>\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Schon haben wir einen Lade-Platzhalter."
    }), "\n", jsxs(_components.p, {
      children: ["Es ist wichtig, sich zu merken, dass es das Lesen einer von einem asynchronen Wert abgeleiteten reaktiven Funktion ist, die ", jsx(_components.code, {
        children: "Suspense"
      }), " auslöst und nicht die asynchrone Abfrage selbst. Wenn ein Ressourcen-Signal (einschließlich ", jsx(_components.code, {
        children: "lazy"
      }), "-Komponenten) nicht innerhalb der ", jsx(_components.code, {
        children: "Suspense"
      }), "-Grenzen gelesen wird, wird es nicht von dessem Effekt betroffen sein."]
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "Suspense"
      }), " ist in vielerlei Hinsicht nur wie eine ", jsx(_components.code, {
        children: "Show"
      }), "-Komponente, die beide Zweige rendert. Während ", jsx(_components.code, {
        children: "Suspense"
      }), " wichtig für asynchrones Server-Rendering ist, sollte man sich nicht verpflichtet fühlen, es zu nutzen, wenn alles im Client gerendert wird. Solids feingranulares Rendering hat keine zusätzlichen Kosten für das manuelle Aufspalten von Dingen."]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "Deferred"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [resume, setResume] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-literal",
          children: "false"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "setTimeout"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setResume"
        }), "(", jsx(_components.span, {
          className: "hljs-literal",
          children: "true"
        }), "), ", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{resume()}"
            }), ">"]
          }), "{props.children}", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), ">"]
          })]
        }), ";\n}\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Alle Arbeit in Solid ist bereits unabhängig voneinander geordnet, daher benötigt man keine Lösungen wie Zeiteinteilung."
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-6283d72f.js.map
