import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["Объединение ", jsx(_components.code, {
        children: "пропсов"
      }), " - не единственная операция, которую мы можем выполнить. Часто мы используем деструктуризацию, чтобы использовать часть ", jsx(_components.code, {
        children: "пропсов"
      }), " в текущем компоненте, а другие передать дочерним компонентам."]
    }), "\n", jsxs(_components.p, {
      children: ["Для этого в Solid есть ", jsx(_components.code, {
        children: "splitProps"
      }), ". Он принимает объект ", jsx(_components.code, {
        children: "props"
      }), " и один или несколько массивов ключей, которые мы хотим извлечь в отдельные объекты ", jsx(_components.code, {
        children: "props"
      }), ". Он возвращает массив объектов ", jsx(_components.code, {
        children: "props"
      }), ", по одному на массив указанных ключей, плюс один объект ", jsx(_components.code, {
        children: "props"
      }), " с оставшимися ключами, аналогично параметру ", jsx(_components.code, {
        children: "rest"
      }), ". Все возвращенные объекты сохраняют реактивность."]
    }), "\n", jsxs(_components.p, {
      children: ["Наш пример не обновляется, когда мы задаем имя, из-за потери реактивности при деструктуризации в ", jsx(_components.code, {
        children: "greeting.tsx"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "Greeting"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " { greeting, name, ...others } = props;\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n\t\t", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "h3"
            }), " {", jsx(_components.span, {
              className: "hljs-attr",
              children: "...others"
            }), "}>"]
          }), "\n\t\t\t{greeting} {name}\n\t\t", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h3"
            }), ">"]
          })]
        }), "\n\t);\n}\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["Сохранить реактивность мы можем с помощью ", jsx(_components.code, {
        children: "splitProps"
      }), ":"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "export"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "default"
        }), " ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "Greeting"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [local, others] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "splitProps"
        }), "(props, [", jsx(_components.span, {
          className: "hljs-string",
          children: "'greeting'"
        }), ", ", jsx(_components.span, {
          className: "hljs-string",
          children: "'name'"
        }), "]);\n\t", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " (\n\t\t", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "h3"
            }), " {", jsx(_components.span, {
              className: "hljs-attr",
              children: "...others"
            }), "}>"]
          }), "\n\t\t\t{local.greeting} {local.name}\n\t\t", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h3"
            }), ">"]
          })]
        }), "\n\t);\n}\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Теперь кнопка работает как положено."
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-65964807.js.map
