import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsx(_components.p, {
      children: "ほとんどの場合、派生 Signal を合成すれば十分です。しかし、重複した作業を減らすために、値をキャッシュすると有益な場合もあります。Memo を使って関数を評価し、その依存関係が変わるまで結果を保存できます。これは、他の依存関係を持つ Effect の計算をキャッシュしたり、DOM ノードの作成などの高価な操作に必要な作業を軽減するのに適しています。"
    }), "\n", jsx(_components.p, {
      children: "Memo は Effect のようなオブザーバーであると同時に、読み取り専用の Signal でもあります。Memo は依存関係とオブザーバーの両方を認識しているため、どのような変更でも一度しか実行されないことを保証できます。これにより、Signal に書き込む Effect を登録するよりも好ましいものとなります。一般的に、派生できるものは、派生させるべきです。"
    }), "\n", jsxs(_components.p, {
      children: ["Memo の作成は、", jsx(_components.code, {
        children: "solid-js"
      }), " からインポートできる ", jsx(_components.code, {
        children: "createMemo"
      }), " に関数を渡すだけで簡単です。この例では、クリックするたびに値を再計算するコストが高くなっていきます。これを ", jsx(_components.code, {
        children: "createMemo"
      }), " でラップすると、1 回のクリックで 1 回だけ再計算されます:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " fib = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createMemo"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "fibonacci"
        }), "(", jsx(_components.span, {
          className: "hljs-title function_",
          children: "count"
        }), "()));\n"]
      })
    }), "\n", jsxs(_components.p, {
      children: ["実行頻度を確認するに、", jsx(_components.code, {
        children: "fib"
      }), " 関数内に ", jsx(_components.code, {
        children: "console.log"
      }), " を設置します:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " fib = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createMemo"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " {\n  ", jsx(_components.span, {
          className: "hljs-variable language_",
          children: "console"
        }), ".", jsx(_components.span, {
          className: "hljs-title function_",
          children: "log"
        }), "(", jsx(_components.span, {
          className: "hljs-string",
          children: "\"Calculating Fibonacci\""
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "fibonacci"
        }), "(", jsx(_components.span, {
          className: "hljs-title function_",
          children: "count"
        }), "());\n});\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-7b4ab58f.js.map
