import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "lazy"
      }), " と ", jsx(_components.code, {
        children: "createResource"
      }), " はそれぞれ単独で使用できますが、Solid は複数の非同期イベントの表示を連携するメカニズムも提供します。", jsx(_components.code, {
        children: "Suspense"
      }), " は、これらの非同期イベントが解決すると、部分的にロードされたコンテンツの代わりにフォールバックのプレースホルダーを表示できる境界として機能します。"]
    }), "\n", jsxs(_components.p, {
      children: ["これにより、中間および部分的なローディング状態が多すぎるために発生する視覚的なジャンクを取り除くことで、ユーザーエクスペリエンスを向上させることができます。", jsx(_components.code, {
        children: "Suspense"
      }), " は、子孫の非同期な読み取りを自動的に検出し、それに応じて動作します。", jsx(_components.code, {
        children: "Suspense"
      }), " コンポーネントは必要なだけネストでき、", jsx(_components.code, {
        children: "loading"
      }), " 状態が検出されると、最も近い祖先だけが ", jsx(_components.code, {
        children: "fallback"
      }), " に変換されます。"]
    }), "\n", jsxs(_components.p, {
      children: ["遅延ロードの例に ", jsx(_components.code, {
        children: "Suspense"
      }), " コンポーネントを追加してみましょう:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<>\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "h1"
            }), ">"]
          }), "Welcome", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h1"
            }), ">"]
          })]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "p"
            }), ">"]
          }), "Loading...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "p"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Greeting"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "name"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "\"Jake\""
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n</>\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "これで、ローディングのプレースホルダーができました。"
    }), "\n", jsxs(_components.p, {
      children: ["重要なのは、", jsx(_components.code, {
        children: "Suspense"
      }), " をトリガーするのは、非同期派生値の読み取りであり、非同期フェッチそのものではありません。Resource の Signal（", jsx(_components.code, {
        children: "lazy"
      }), " コンポーネントを含む）が ", jsx(_components.code, {
        children: "Suspense"
      }), " の境界の下で読み取られない場合、サスペンドしません。"]
    }), "\n", jsxs(_components.p, {
      children: [jsx(_components.code, {
        children: "Suspense"
      }), " は多くの意味で、両方のブランチをレンダリングする ", jsx(_components.code, {
        children: "Show"
      }), " コンポーネントに過ぎません。", jsx(_components.code, {
        children: "Suspense"
      }), " は非同期のサーバーレンダリングには欠かせないものですが、クライアントレンダリングされたコードにすぐに使う必要はありません。Solid のきめ細かなレンダリングは、手動で物事を分割するための追加コストはありません。"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: [jsx(_components.span, {
          className: "hljs-keyword",
          children: "function"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "Deferred"
        }), "(", jsx(_components.span, {
          className: "hljs-params",
          children: "props"
        }), ") {\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "const"
        }), " [resume, setResume] = ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "createSignal"
        }), "(", jsx(_components.span, {
          className: "hljs-literal",
          children: "false"
        }), ");\n  ", jsx(_components.span, {
          className: "hljs-built_in",
          children: "setTimeout"
        }), "(", jsx(_components.span, {
          className: "hljs-function",
          children: "() =>"
        }), " ", jsx(_components.span, {
          className: "hljs-title function_",
          children: "setResume"
        }), "(", jsx(_components.span, {
          className: "hljs-literal",
          children: "true"
        }), "), ", jsx(_components.span, {
          className: "hljs-number",
          children: "0"
        }), ");\n\n  ", jsx(_components.span, {
          className: "hljs-keyword",
          children: "return"
        }), " ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "when"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{resume()}"
            }), ">"]
          }), "{props.children}", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Show"
            }), ">"]
          })]
        }), ";\n}\n"]
      })
    }), "\n", jsx(_components.p, {
      children: "Solid の作業はすべて独立してキューに入っています。Time Slicing のようなものは必要ありません。"
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-c6038866.js.map
