import { jsx, jsxs, Fragment } from 'solid-jsx/jsx-runtime';

/*@jsxRuntime automatic @jsxImportSource solid-jsx*/
const toc = [];
function _createMdxContent(props) {
  const _components = Object.assign({
    p: "p",
    code: "code",
    pre: "pre",
    span: "span"
  }, props.components);
  return jsxs(Fragment, {
    children: [jsxs(_components.p, {
      children: ["때로는 조정하고 싶은 ", jsx(_components.code, {
        children: "Suspense"
      }), " 컴포넌트가 여러 개 있을 것입니다. 사용 가능한 하나의 접근 방식은 모든 것을 단일 ", jsx(_components.code, {
        children: "Suspense"
      }), " 아래에 두는 것이지만, 이는 하나의 로딩 동작만 사용하도록 제한합니다. 단일 폴백 상태는 마지막 항목이 로드될 때까지 모든 항목이 기다리야 함을 의미합니다. 이를 해결하기 위해 Solid는 대신 ", jsx(_components.code, {
        children: "SuspenseList"
      }), " 컴포넌트를 도입합니다."]
    }), "\n", jsxs(_components.p, {
      children: ["예제와 같이 여러 ", jsx(_components.code, {
        children: "Suspense"
      }), " 컴포넌트가 있다고 해봅시다. ", jsx(_components.code, {
        children: "revealOrder"
      }), "를 ", jsx(_components.code, {
        children: "forwards"
      }), "로 설정한 ", jsx(_components.code, {
        children: "SuspenseList"
      }), "로 래핑하면, 로드 순서에 상관없이 트리에 나타나는 순서대로 렌더링됩니다. 이렇게 하면 페이지가 점핑하는 것이 줄어듭니다. ", jsx(_components.code, {
        children: "revealOrder"
      }), "를 ", jsx(_components.code, {
        children: "backwards"
      }), "나 ", jsx(_components.code, {
        children: "together"
      }), "로 설정하게 되면, 순서를 반대로 하거나 모든 Suspense 컴포넌트가 로드될 때까지 기다립니다. 또한 ", jsx(_components.code, {
        children: "tail"
      }), " 옵션이 있는데 ", jsx(_components.code, {
        children: "hidden"
      }), "이나 ", jsx(_components.code, {
        children: "collapsed"
      }), "로 설정함으로써, ", jsx(_components.code, {
        children: "revealOrder"
      }), " 설정값을 오버라이드해서 폴백 상태를 표시하거나 표시하지 않도록 합니다."]
    }), "\n", jsxs(_components.p, {
      children: ["예제는 플레이스홀더 로드 측면에서 약간 엉망입니다. 모든 데이터를 독립적으로 로딩하면서, 데이터 로딩 순서에 따라 여러 플레이스홀더를 표시하는 경우가 많습니다. ", jsx(_components.code, {
        children: "ProfilePage"
      }), " 컴포넌트의 JSX를 ", jsx(_components.code, {
        children: "<SuspenseList>"
      }), "로 래핑해 보겠습니다:"]
    }), "\n", jsx(_components.pre, {
      children: jsxs(_components.code, {
        className: "hljs language-jsx",
        children: ["<", jsx(_components.span, {
          className: "hljs-title class_",
          children: "SuspenseList"
        }), " revealOrder=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"forwards\""
        }), " tail=", jsx(_components.span, {
          className: "hljs-string",
          children: "\"collapsed\""
        }), ">\n  ", jsx(_components.span, {
          className: "xml",
          children: jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileDetails"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "user"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.user}"
            }), " />"]
          })
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "h2"
            }), ">"]
          }), "Loading posts...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h2"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileTimeline"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "posts"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.posts}"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n  ", jsxs(_components.span, {
          className: "xml",
          children: [jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "fallback"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{"
            }), "<", jsx(_components.span, {
              className: "hljs-attr",
              children: "h2"
            }), ">"]
          }), "Loading fun facts...", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "h2"
            }), ">"]
          }), "}>\n    ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["<", jsx(_components.span, {
              className: "hljs-name",
              children: "ProfileTrivia"
            }), " ", jsx(_components.span, {
              className: "hljs-attr",
              children: "trivia"
            }), "=", jsx(_components.span, {
              className: "hljs-string",
              children: "{props.trivia}"
            }), " />"]
          }), "\n  ", jsxs(_components.span, {
            className: "hljs-tag",
            children: ["</", jsx(_components.span, {
              className: "hljs-name",
              children: "Suspense"
            }), ">"]
          })]
        }), "\n</", jsx(_components.span, {
          className: "hljs-title class_",
          children: "SuspenseList"
        }), ">\n"]
      })
    })]
  });
}
function MDXContent(props = {}) {
  const {wrapper: MDXLayout} = props.components || ({});
  return MDXLayout ? jsx(MDXLayout, Object.assign({}, props, {
    children: jsx(_createMdxContent, props)
  })) : _createMdxContent(props);
}

export { MDXContent as default, toc };
//# sourceMappingURL=lesson-e36dc438.js.map
